from flask import Flask
import logset
from recordJob import jobStart
import controller  # 导入 controller.py 文件
app = Flask(__name__)


# 设置日志
logger = logset.setup_logging()


# 初始化路由
controller.init_routes(app)
# 启动定时任务
jobStart()

def main():
    logger.info("Starting App")
    app.run(host='127.0.0.1', port=5000)

if __name__ == '__main__':
    main()







